@@ -15,19 +15,20 @@
 #include "choices.h"
 
 static void chomp(char *, ssize_t);
+static char * eager_strpbrk(const char *, const char *);
 
 struct choices *
 io_read_choices(int read_descriptions)
 {
-	char *line, *description, *field_separator;
+	char *line, *description, *field_separators;
 	size_t line_size;
 	ssize_t length;
 	struct choice *choice;
 	struct choices *choices;
 
-	field_separator = getenv("IFS");
-	if (field_separator == NULL) {
-		field_separator = " ";
+	field_separators = getenv("IFS");
+	if (field_separators == NULL) {
+		field_separators = " ";
 	}
 
 	choices = malloc(sizeof(struct choices));
@@ -39,7 +40,6 @@ io_read_choices(int read_descriptions)
 
 	for (;;) {
 		line = NULL;
-		description = "";
 		line_size = 0;
 
 		length = getline(&line, &line_size, stdin);
@@ -49,8 +49,10 @@ io_read_choices(int read_descriptions)
 
 		chomp(line, length);
 
-		if (read_descriptions) {
-			strtok_r(line, field_separator, &description);
+		if (read_descriptions && (description = eager_strpbrk(line, field_separators))) {
+			*description++ = '\0';
+		} else {
+			description = "";
 		}
 
 		choice = choice_new(line, description, 1);
@@ -81,3 +83,14 @@ chomp(char *string, ssize_t length)
 		string[length - 1] = '\0';
 	}
 }
+
+static char *
+eager_strpbrk(const char *string, const char *separators) {
+	char *ptr = NULL, *tmp_ptr;
+	for (tmp_ptr = strpbrk(string, separators);
+	     tmp_ptr;
+	     tmp_ptr = strpbrk(tmp_ptr, separators)) {
+		ptr = tmp_ptr++;
+	}
+	return ptr;
+}
