@@ -4,6 +4,6 @@
 #include "choice.h"
 #include "choices.h"
 
-struct choice    *get_selected(struct choices *, char *, int);
+struct choice	*ui_selected_choice(struct choices *, char *, int);
 
 #endif /* UI_H */
